@@ -1,11 +1,13 @@
 import json
 import click
 import logging
+from pathlib import Path
 
 from alephclient import settings
 from alephclient.api import AlephAPI
 from alephclient.errors import AlephException
 from alephclient.crawldir import crawl_dir
+from alephclient.fetchdir import fetch_collection, fetch_entity
 
 log = logging.getLogger(__name__)
 
@@ -83,6 +85,38 @@ def crawldir(ctx, path, foreign_id, language=None, casefile=False, noindex=False
         raise click.ClickException(str(exc))
 
 
+@cli.command()
+@click.option("-f", "--foreign-id", help="foreign_id of the collection")
+@click.option("-e", "--entity-id", help="id of the root entity to download")
+@click.option(
+    "-p",
+    "--prefix",
+    type=click.Path(writable=True),
+    help="destination path for the download",
+)
+@click.option(
+    "--overwrite",
+    is_flag=True,
+    default=False,
+    help="overwrite existing files",
+)
+@click.pass_context
+def fetchdir(ctx, foreign_id, prefix=None, entity_id=None, overwrite=False):
+    """Recursively download the contents of an Aleph entity or collection and rebuild
+    them as a folder tree."""
+    try:
+        api = ctx.obj["api"]
+        if entity_id is not None:
+            fetch_entity(api, prefix, entity_id, overwrite=overwrite)
+        elif foreign_id is not None:
+            fetch_collection(api, prefix, foreign_id, overwrite=overwrite)
+        else:
+            msg = "Please specify either a foreign_id or entity_id"
+            raise click.ClickException(msg)
+    except AlephException as exc:
+        raise click.ClickException(str(exc))
+
+
 @cli.command("reingest")
 @click.option("-f", "--foreign-id", required=True, help="foreign_id of the collection")
 @click.option(
@@ -269,7 +303,7 @@ def make_list(ctx, foreign_id, outfile, label, summary):
     try:
         collection_id = _get_id_from_foreign_key(api, foreign_id)
         res = api.create_entityset(collection_id, "list", label, summary)
-        _write_result(outfile, [res])
+        outfile.write(res.get("id"))
     except AlephException as exc:
         raise click.ClickException(exc.message)
     except BrokenPipeError:
